==> aster-full-src-7.4.0-4.tar.gz: STA7.4/bibfor/prepost/irgmpv.f <==
      SUBROUTINE IRGMPV ( IFI, LRESU, NOMCON, CHAMSY, NBORDR, PARA,  
     +                    NOCMP, NBEL, SCAL, VECT, TENS, VERSIO)
      IMPLICIT NONE
C
      INTEGER        IFI, NBORDR, LCH,ICH, VERSIO
      REAL*8         PARA(*)
      LOGICAL        LRESU, SCAL, VECT, TENS
      CHARACTER*8    NOCMP
      CHARACTER*(*)  NOMCON, CHAMSY
C     NBRE POUR CHAQUE TYPE D'ELEMENT
      INTEGER        NBEL(*)
C     ------------------------------------------------------------------
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF PREPOST  DATE 13/02/2004   AUTEUR MCOURTOI M.COURTOIS 
C ======================================================================
C COPYRIGHT (C) 1991 - 2002  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR   
C (AT YOUR OPTION) ANY LATER VERSION.                                 
C
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT 
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF          
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU    
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.                            
C
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE   
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,       
C    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.      
C ======================================================================
C
C     BUT :   ECRITURE D'UN RESULTAT AU FORMAT GMSH
C
C     ------------------------------------------------------------------
      INTEGER      IOR,LXLGUT
      CHARACTER*19 K19B
      CHARACTER*36 K36B
      INTEGER     NBPOI, NBSEG, NBTRI, NBTET, NBQUA, NBPYR, NBPRI, NBHEX
      INTEGER      TYPPOI, TYPSEG, TYPTRI, TYPTET, TYPQUA,
     +             TYPPYR, TYPPRI, TYPHEX
      CHARACTER*32 JEXNOM
C     ------------------------------------------------------------------
C
      CALL JENONU ( JEXNOM('&CATA.TM.NOMTM', 'POI1'   ), TYPPOI )
      CALL JENONU ( JEXNOM('&CATA.TM.NOMTM', 'SEG2'   ), TYPSEG )
      CALL JENONU ( JEXNOM('&CATA.TM.NOMTM', 'TRIA3'  ), TYPTRI )
      CALL JENONU ( JEXNOM('&CATA.TM.NOMTM', 'QUAD4'  ), TYPQUA )
      CALL JENONU ( JEXNOM('&CATA.TM.NOMTM', 'TETRA4' ), TYPTET )
      CALL JENONU ( JEXNOM('&CATA.TM.NOMTM', 'PYRAM5' ), TYPPYR )
      CALL JENONU ( JEXNOM('&CATA.TM.NOMTM', 'PENTA6' ), TYPPRI )
      CALL JENONU ( JEXNOM('&CATA.TM.NOMTM', 'HEXA8' ) , TYPHEX )
      NBPOI=NBEL(TYPPOI)
      NBSEG=NBEL(TYPSEG)
      NBTRI=NBEL(TYPTRI)
      NBQUA=NBEL(TYPQUA)
      NBTET=NBEL(TYPTET)
      NBPYR=NBEL(TYPPYR)
      NBPRI=NBEL(TYPPRI)
      NBHEX=NBEL(TYPHEX)
C
      WRITE(IFI,1000) '$View'
C
C     ECRITURE DE LIGNE 1 (VIEW_NAME NB_TIME_STEPS)
C
      IF ( LRESU ) THEN 
         LCH = LXLGUT(NOMCON)
         K36B(1:LCH) = NOMCON(1:LCH)
         ICH=LCH+1
         K36B(ICH:ICH) = '_'
         LCH=LXLGUT(CHAMSY)
         K36B(ICH+1:ICH+LCH) = CHAMSY(1:LCH)
         ICH=ICH+LCH+1
         K36B(ICH:ICH) = '_'
         LCH=LXLGUT(NOCMP)
         K36B(ICH+1:ICH+LCH) = NOCMP(1:LCH)
         K36B(ICH+LCH+1:ICH+LCH+1) = ' '
         WRITE(IFI,1020) K36B(1:ICH+LCH+1), NBORDR   
      ELSE
         LCH = LXLGUT(NOMCON)
         K19B(1:LCH) = NOMCON(1:LCH)
         ICH=LCH+1
         K19B(ICH:ICH) = '_'
         LCH=LXLGUT(NOCMP)
         K19B(ICH+1:ICH+LCH) = NOCMP(1:LCH)
         K19B(ICH+LCH+1:ICH+LCH+1) = ' '
         WRITE(IFI,1022) K19B(1:ICH+LCH+1), NBORDR
      ENDIF
C
C     ECRITURE DE LA LIGNE 2 A 4 (nb elt par de type de maille)
C
      IF ( SCAL ) THEN 
         WRITE(IFI,1030) NBPOI, 0, 0
         WRITE(IFI,1030) NBSEG, 0, 0
         WRITE(IFI,1030) NBTRI, 0, 0
         IF (VERSIO.EQ.2) THEN
           WRITE(IFI,1030) NBQUA, 0, 0
         ENDIF
         WRITE(IFI,1030) NBTET, 0, 0
         IF (VERSIO.EQ.2) THEN
           WRITE(IFI,1030) NBHEX, 0, 0
           WRITE(IFI,1030) NBPRI, 0, 0
           WRITE(IFI,1030) NBPYR, 0, 0
         ENDIF
      ELSEIF ( VECT ) THEN 
         WRITE(IFI,1030) 0, NBPOI, 0
         WRITE(IFI,1030) 0, NBSEG, 0
         WRITE(IFI,1030) 0, NBTRI, 0
         IF (VERSIO.EQ.2) THEN
           WRITE(IFI,1030) 0, NBQUA, 0
         ENDIF
         WRITE(IFI,1030) 0, NBTET, 0
         IF (VERSIO.EQ.2) THEN
           WRITE(IFI,1030) 0, NBHEX, 0
           WRITE(IFI,1030) 0, NBPRI, 0
           WRITE(IFI,1030) 0, NBPYR, 0
         ENDIF
      ELSEIF ( TENS ) THEN 
         WRITE(IFI,1030) 0, 0, NBPOI
         WRITE(IFI,1030) 0, 0, NBSEG
         WRITE(IFI,1030) 0, 0, NBTRI
         IF (VERSIO.EQ.2) THEN
           WRITE(IFI,1030) 0, 0, NBQUA
         ENDIF
         WRITE(IFI,1030) 0, 0, NBTET
         IF (VERSIO.EQ.2) THEN
           WRITE(IFI,1030) 0, 0, NBHEX
           WRITE(IFI,1030) 0, 0, NBPRI
           WRITE(IFI,1030) 0, 0, NBPYR
         ENDIF
      ELSE
      ENDIF

      IF (VERSIO.EQ.2) THEN
        WRITE(IFI,1050) 0,0,0,0
      ENDIF
C
C     ECRITURE DE LA LIGNE 5 (time_step_values)
C
      WRITE(IFI,1040) (PARA(IOR), IOR=1,NBORDR)
C
 1000 FORMAT(A5)
 1020 FORMAT(A,1X,I4)
 1022 FORMAT(A,1X,I4)
 1030 FORMAT(3(I6,1X))
 1040 FORMAT(1P,10(E15.8,1X))
 1050 FORMAT(4(I6,1X))
C
      END

==> aster-full-src-8.1.0-1.tar.gz: STA8.1/bibfor/prepost/irgmpv.f <==
      SUBROUTINE IRGMPV ( IFI, LRESU, NOMCON, CHAMSY, NBORDR, PARA,  
     +                    NOCMP, NBEL, SCAL, VECT, TENS, VERSIO)
      IMPLICIT NONE
C
      INTEGER        IFI, NBORDR, LCH,ICH, VERSIO
      REAL*8         PARA(*)
      LOGICAL        LRESU, SCAL, VECT, TENS
      CHARACTER*8    NOCMP
      CHARACTER*(*)  NOMCON, CHAMSY
C     NBRE POUR CHAQUE TYPE D'ELEMENT
      INTEGER        NBEL(*)
C     ------------------------------------------------------------------
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF PREPOST  DATE 12/04/2005   AUTEUR CIBHHPD L.SALMONA 
C ======================================================================
C COPYRIGHT (C) 1991 - 2002  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR   
C (AT YOUR OPTION) ANY LATER VERSION.                                 
C
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT 
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF          
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU    
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.                            
C
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE   
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,       
C    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.      
C ======================================================================
C
C     BUT :   ECRITURE D'UN RESULTAT AU FORMAT GMSH
C
C     ------------------------------------------------------------------
      INTEGER      IOR,LXLGUT
      CHARACTER*19 K19B
      CHARACTER*36 K36B
      INTEGER     NBPOI, NBSEG, NBTRI, NBTET, NBQUA, NBPYR, NBPRI, NBHEX
      INTEGER      TYPPOI, TYPSEG, TYPTRI, TYPTET, TYPQUA,
     +             TYPPYR, TYPPRI, TYPHEX
      CHARACTER*32 JEXNOM
C     ------------------------------------------------------------------
C
      CALL JENONU ( JEXNOM('&CATA.TM.NOMTM', 'POI1'   ), TYPPOI )
      CALL JENONU ( JEXNOM('&CATA.TM.NOMTM', 'SEG2'   ), TYPSEG )
      CALL JENONU ( JEXNOM('&CATA.TM.NOMTM', 'TRIA3'  ), TYPTRI )
      CALL JENONU ( JEXNOM('&CATA.TM.NOMTM', 'QUAD4'  ), TYPQUA )
      CALL JENONU ( JEXNOM('&CATA.TM.NOMTM', 'TETRA4' ), TYPTET )
      CALL JENONU ( JEXNOM('&CATA.TM.NOMTM', 'PYRAM5' ), TYPPYR )
      CALL JENONU ( JEXNOM('&CATA.TM.NOMTM', 'PENTA6' ), TYPPRI )
      CALL JENONU ( JEXNOM('&CATA.TM.NOMTM', 'HEXA8' ) , TYPHEX )
      NBPOI=NBEL(TYPPOI)
      NBSEG=NBEL(TYPSEG)
      NBTRI=NBEL(TYPTRI)
      NBQUA=NBEL(TYPQUA)
      NBTET=NBEL(TYPTET)
      NBPYR=NBEL(TYPPYR)
      NBPRI=NBEL(TYPPRI)
      NBHEX=NBEL(TYPHEX)
C
      WRITE(IFI,1000) '$View'
C
C     ECRITURE DE LIGNE 1 (VIEW_NAME NB_TIME_STEPS)
C
      IF ( LRESU ) THEN 
         LCH = LXLGUT(NOMCON)
         K36B(1:LCH) = NOMCON(1:LCH)
         ICH=LCH+1
         K36B(ICH:ICH) = '_'
         LCH=LXLGUT(CHAMSY)
         K36B(ICH+1:ICH+LCH) = CHAMSY(1:LCH)
         ICH=ICH+LCH+1
         K36B(ICH:ICH) = '_'
         LCH=LXLGUT(NOCMP)
         K36B(ICH+1:ICH+LCH) = NOCMP(1:LCH)
         K36B(ICH+LCH+1:ICH+LCH+1) = ' '
         WRITE(IFI,1020) K36B(1:ICH+LCH+1), NBORDR   
      ELSE
         LCH = LXLGUT(NOMCON)
         K19B(1:LCH) = NOMCON(1:LCH)
         ICH=LCH+1
         K19B(ICH:ICH) = '_'
         LCH=LXLGUT(NOCMP)
         K19B(ICH+1:ICH+LCH) = NOCMP(1:LCH)
         K19B(ICH+LCH+1:ICH+LCH+1) = ' '
         WRITE(IFI,1022) K19B(1:ICH+LCH+1), NBORDR
      ENDIF
C
C     ECRITURE DE LA LIGNE 2 A 4 (nb elt par de type de maille)
C
      IF ( SCAL ) THEN 
         WRITE(IFI,1030) NBPOI, 0, 0
         WRITE(IFI,1030) NBSEG, 0, 0
         WRITE(IFI,1030) NBTRI, 0, 0
         IF (VERSIO.EQ.2) THEN
           WRITE(IFI,1030) NBQUA, 0, 0
         ENDIF
         WRITE(IFI,1030) NBTET, 0, 0
         IF (VERSIO.EQ.2) THEN
           WRITE(IFI,1030) NBHEX, 0, 0
           WRITE(IFI,1030) NBPRI, 0, 0
           WRITE(IFI,1030) NBPYR, 0, 0
         ENDIF
      ELSEIF ( VECT ) THEN 
         WRITE(IFI,1030) 0, NBPOI, 0
         WRITE(IFI,1030) 0, NBSEG, 0
         WRITE(IFI,1030) 0, NBTRI, 0
         IF (VERSIO.EQ.2) THEN
           WRITE(IFI,1030) 0, NBQUA, 0
         ENDIF
         WRITE(IFI,1030) 0, NBTET, 0
         IF (VERSIO.EQ.2) THEN
           WRITE(IFI,1030) 0, NBHEX, 0
           WRITE(IFI,1030) 0, NBPRI, 0
           WRITE(IFI,1030) 0, NBPYR, 0
         ENDIF
      ELSEIF ( TENS ) THEN 
         WRITE(IFI,1030) 0, 0, NBPOI
         WRITE(IFI,1030) 0, 0, NBSEG
         WRITE(IFI,1030) 0, 0, NBTRI
         IF (VERSIO.EQ.2) THEN
           WRITE(IFI,1030) 0, 0, NBQUA
         ENDIF
         WRITE(IFI,1030) 0, 0, NBTET
         IF (VERSIO.EQ.2) THEN
           WRITE(IFI,1030) 0, 0, NBHEX
           WRITE(IFI,1030) 0, 0, NBPRI
           WRITE(IFI,1030) 0, 0, NBPYR
         ENDIF
      ELSE
      ENDIF

      IF (VERSIO.EQ.2) THEN
        WRITE(IFI,1050) 0,0,0,0
      ENDIF
C
C     ECRITURE DE LA LIGNE 5 (time_step_values)
C
      WRITE(IFI,1040) (PARA(IOR), IOR=1,NBORDR)
C
 1000 FORMAT(A5)
 1020 FORMAT(A,1X,I4)
 1022 FORMAT(A,1X,I4)
 1030 FORMAT(3(I8,1X))
 1040 FORMAT(1P,10(E15.8,1X))
 1050 FORMAT(4(I6,1X))
C
      END
